[GRASS-SVN] r72641 - grass-addons/grass7/vector/v.gsflow.grid

svn_grass at osgeo.org svn_grass at osgeo.org
Sun Apr 22 09:10:02 PDT 2018


Author: awickert
Date: 2018-04-22 09:10:02 -0700 (Sun, 22 Apr 2018)
New Revision: 72641

Modified:
   grass-addons/grass7/vector/v.gsflow.grid/v.gsflow.grid.py
Log:
v.gsflow.grid fix: grass. --> gscript.


Modified: grass-addons/grass7/vector/v.gsflow.grid/v.gsflow.grid.py
===================================================================
--- grass-addons/grass7/vector/v.gsflow.grid/v.gsflow.grid.py	2018-04-22 16:09:06 UTC (rev 72640)
+++ grass-addons/grass7/vector/v.gsflow.grid/v.gsflow.grid.py	2018-04-22 16:10:02 UTC (rev 72641)
@@ -122,13 +122,13 @@
     _lena0 = (len(raster_input) == 0)
     _lenb0 = (len(raster_output) == 0)
     if _lena0 + _lenb0 == 1:
-        grass.fatal("You must set both raster input and output, or neither.")
+        gscript.fatal("You must set both raster input and output, or neither.")
     """
     
     # Fatal if bc_cell set but mask and grid are false
     if bc_cell != '':
         if (mask == '') or (pp == ''):
-            grass.fatal('Mask and pour point must be set to define b.c. cell')
+            gscript.fatal('Mask and pour point must be set to define b.c. cell')
         
     # Create grid -- overlaps DEM, three cells of padding
     gscript.use_temp_region()
@@ -217,7 +217,7 @@
 
     # Next point downstream of the pour point
     # Requires pp (always) and mask (sometimes)
     # Dependency set above w/ grass.fatal
     if len(bc_cell) > 0:
         ########## NEED TO USE TRUE TEMPORARY FILE ##########
         # May not work with dx != dy!
@@ -266,7 +266,7 @@
             _ismask_2 = int(_ismask_2['values'].values()[0][0])
             # If both covered by mask, error
             if _ismask_1 and _ismask_2:
-                grass.fatal('All possible b.c. cells covered by basin mask.\n\
+                gscript.fatal('All possible b.c. cells covered by basin mask.\n\
                              Contact the developer: awickert (at) umn(.)edu')
             # Otherwise, those that keep those that are not covered by basin
             # mask and set ...
@@ -217,7 +217,7 @@
     # Next point downstream of the pour point
     # Requires pp (always) and mask (sometimes)
-    # Dependency set above w/ grass.fatal
+    # Dependency set above w/ gscript.fatal
     if len(bc_cell) > 0:
         ########## NEED TO USE TRUE TEMPORARY FILE ##########



More information about the grass-commit mailing list